@@ -1,4 +1,5 @@
 """Bokeh rankplot."""
+
 import numpy as np
 
 from bokeh.models import Span
@@ -6,7 +7,7 @@ from bokeh.models.annotations import Title
 from bokeh.models.tickers import FixedTicker
 
 from ....stats.density_utils import histogram
-from ...plot_utils import _scale_fig_size, make_label, compute_ranks
+from ...plot_utils import _scale_fig_size, compute_ranks
 from .. import show_layout
 from . import backend_kwarg_defaults, create_axes_grid
 
@@ -23,6 +24,7 @@ def plot_rank(
     colors,
     ref_line,
     labels,
+    labeller,
     ref_line_kwargs,
     bar_kwargs,
     vlines_kwargs,
@@ -71,7 +73,7 @@ def plot_rank(
     else:
         axes = np.atleast_2d(axes)
 
-    for ax, (var_name, selection, var_data) in zip(
+    for ax, (var_name, selection, isel, var_data) in zip(
         (item for item in axes.flatten() if item is not None), plotters
     ):
         ranks = compute_ranks(var_data)
@@ -138,7 +140,7 @@ def plot_rank(
             ax.yaxis.major_label_text_font_size = "0pt"
 
         _title = Title()
-        _title.text = make_label(var_name, selection)
+        _title.text = labeller.make_label_vert(var_name, selection, isel)
         ax.title = _title
 
     show_layout(axes, show)
